@@ -4,8 +4,8 @@ Find pericenters and apocenters using Amplitude.
 Part of Eccentricity Definition project.
 Md Arif Shaikh, Mar 28, 2022
 """
-from .eccDefinition import eccDefinition
 from scipy.signal import find_peaks
+from .eccDefinition import eccDefinition
 
 
 class eccDefinitionUsingAmplitude(eccDefinition):
@@ -20,7 +20,7 @@ class eccDefinitionUsingAmplitude(eccDefinition):
         """
         super().__init__(*args, **kwargs)
         self.data_for_finding_extrema = self.get_data_for_finding_extrema()
-        self.label_for_data_for_finding_extrema = r"$A_{22}$"
+        self.label_for_data_for_finding_extrema = self.get_label_for_plots("amp")
         self.method = "Amplitude"
 
     def get_data_for_finding_extrema(self):
@@ -29,13 +29,13 @@ class eccDefinitionUsingAmplitude(eccDefinition):
         In the derived classes, one need to override this function
         to return the appropriate data that is to be used. For example,
         in residual amplitude method, this function would return
-        residual amp22, whereas for frequency method, it would
+        residual amp_gw, whereas for frequency method, it would
         return omega22 and so on.
         """
-        return self.amp22
+        return self.amp_gw
 
     def find_extrema(self, extrema_type="pericenters"):
-        """Find the extrema in the amp22.
+        """Find the extrema in the amp_gw.
 
         parameters:
         -----------
