@@ -1,9 +1,16 @@
 """Fancy settings for plots."""
 from matplotlib import rc
 from cycler import cycler
-from matplotlib import colormaps
+from packaging import version
 
-dark2 = colormaps["Dark2"].colors
+# Getting colormaps in matplotlib has changed from v3.5.0
+import matplotlib
+if version.parse(matplotlib.__version__) < version.parse("3.5.0"):
+    from matplotlib import cm
+    dark2 = cm.get_cmap("Dark2").colors
+else:
+    from matplotlib import colormaps
+    dark2 = colormaps["Dark2"].colors
 
 colorsDict = {
     "default": dark2[1],  # brown
@@ -125,8 +132,9 @@ def use_fancy_plotsettings(usetex=True, style="Notebook"):
     rc("legend", frameon=False)
     rc("legend", fontsize=fontSizeDict[style])
     # Fonts
-    rc("font", family="serif")
-    rc("font", serif="times")
+    if usetex:
+        rc("font", family="serif")
+        rc("font", serif="times")
     rc("font", size=fontSizeDict[style])
     # Lines
     rc("lines", linewidth=1.0)
@@ -178,5 +186,26 @@ labelsDict = {
     "chi1z": r"$\chi_{1z}$",
     "chi2z": r"$\chi_{2z}$",
     "h22_real": r"Re[$\mathpzc{h}_{22}$]",
-    "chirp_mass": r"$\mathcal{M}$"
+    "chirp_mass": r"$\mathcal{M}$",
+    "amp_gw": r"$A_{\mathrm{gw}}$",
+    "phase_gw": r"$\Phi_{\mathrm{gw}}$",
+    "omega_gw": r"$\omega_{\mathrm{gw}}$",
+    "amp_gw_fit": r"$A^{\mathrm{fit}}_{\mathrm{gw}}$",
+    "omega_gw_fit": r"$\omega^{\mathrm{fit}}_{\mathrm{gw}}$",
+    "omega_gw_fit_pericenters": r"$\omega^{\mathrm{fit,p}}_{\mathrm{gw}}$",
+    "omega_gw_fit_apocenters": r"$\omega^{\mathrm{fit,a}}_{\mathrm{gw}}$",
+    "omega_gw_pericenters": r"$\omega^{\mathrm{p}}_{\mathrm{gw}}$",
+    "omega_gw_apocenters": r"$\omega^{\mathrm{a}}_{\mathrm{gw}}$",
+    "omega_gw_average": r"$\langle\omega_{\mathrm{gw}}\rangle$",
+    "omega_gw_average_dimless": r"$\langle\omega_{\mathrm{gw}}\rangle$ [rad/$M$]",
+    "f_gw_average": r"$\langle f_{\mathrm{gw}}\rangle$",
+    "f_gw_average_ref": r"$\langle f_{\mathrm{gw, ref}}\rangle$",
+    "f_gw_ref": r"$f_{\mathrm{gw, ref}}$",
+    "res_omega_gw": r"$\Delta\omega_{\mathrm{gw}}$",
+    "res_omega_gw_dimless": r"$\Delta\omega_{\mathrm{gw}}$ [rad/$M$]",
+    "res_amp_gw": r"$\Delta A_{\mathrm{gw}}$",
+    "omega22_copr_symm": r"$\omega_{22}^{\mathrm{copr, sym}}$",
+    "amp22_copr_symm": r"$A_{22}^{\mathrm{copr, sym}}$",
+    "res_omega22_copr_symm": r"$\Delta \omega_{22}^{\mathrm{copr, sym}}$",
+    "res_amp22_copr_symm": r"$\Delta A_{22}^{\mathrm{copr, sym}}$" 
 }
