@@ -1,26 +1,36 @@
 """Useful functions for the project."""
 import numpy as np
 import argparse
+from polyrat import StabilizedSKRationalApproximation
 from scipy.interpolate import InterpolatedUnivariateSpline
 from scipy.interpolate import PchipInterpolator
 import warnings
 
 
-def amplitude_using_all_modes(mode_dict):
+def amplitude_using_all_modes(mode_dict, data_type="hlm"):
     """Get the amplitude using all the available modes.
 
-    Parameters:
+    Parameters
     ----------
-    mode_dict:
+    mode_dict: dict
         Dictionary containing waveform modes.
+    data_type: str
+        Indicate whether the dictionary contains hlm or amplm.
+        Default is "hlm".
 
-    Returns:
+    Returns
+    -------
         Square root of the qudrature sum of the amplitudes of all the
         available modes in mode_dict.
     """
     amp = 0
     for mode in mode_dict.keys():
-        amp += np.abs(mode_dict[mode])**2
+        if data_type == "hlm":
+            amp += np.abs(mode_dict[mode])**2
+        elif data_type == "amplm":
+            amp += mode_dict[mode]**2
+        else:
+            raise KeyError("data_type must be either `hlm` or `amplm`.")
     return np.sqrt(amp)
 
 
@@ -31,15 +41,15 @@ def peak_time_via_quadratic_fit(t, func):
     Fits the function to a quadratic over the 5 points closest to the argmax
     func.
 
-    Parameters:
-    -----------
+    Parameters
+    ----------
     t:
         An array of times.
     func:
         Array of function values.
 
-    Returns:
-    --------
+    Returns
+    -------
     tpeak:
         Time at peak of the function func.
     fpeak:
@@ -70,7 +80,7 @@ def check_kwargs_and_set_defaults(user_kwargs=None,
                                   location=None):
     """Sanity check user given dicionary of kwargs and set default values.
 
-    Parameters:
+    Parameters
     ----------
     user_kwargs:
         Dictionary of kwargs by user.
@@ -81,8 +91,8 @@ def check_kwargs_and_set_defaults(user_kwargs=None,
     location:
         string pointing to where the defaults are defined
 
-    Returns:
-    --------
+    Returns
+    -------
     updated user_kwargs
     """
     # make user_kwargs iterable
@@ -131,15 +141,15 @@ def time_deriv_4thOrder(y, dt):
     Assuming constant time step.
     Tested for convergence up to 1e-12 level.
 
-    Parameters:
-    -----------
+    Parameters
+    ----------
     y:
         1d array to take time derivative of.
     dt:
         Time step.
 
-    Returns:
-    --------
+    Returns
+    -------
     dydt:
         Fourth order time derivative of y.
     """
@@ -177,8 +187,8 @@ def interpolate(newX,
                 check_kwargs=True):
     """Interpolate.
 
-    Parameters:
-    -----------
+    Parameters
+    ----------
     newX:
         Points where interpolant is to be evaluated.
     oldX:
@@ -199,8 +209,8 @@ def interpolate(newX,
     check_kwargs:
         Check spline_kwargs if check_kwargs is True. Default is True.
 
-    Returns:
-    --------
+    Returns
+    -------
     newY:
         Intepolated values at newX.
     """
@@ -233,8 +243,8 @@ def get_interpolant(oldX,
                     check_kwargs=True):
     """Create Interpolant.
 
-    Parameters:
-    -----------
+    Parameters
+    ----------
     oldX:
         1d array of monotonically increasing real values.
     oldY:
@@ -258,8 +268,8 @@ def get_interpolant(oldX,
     check_kwargs:
         Check spline_kwargs if check_kwargs is True. Default is True.
 
-    Returns:
-    --------
+    Returns
+    -------
     Intepolatnt.
     """
     if not np.all(np.diff(oldX) > 0):
@@ -308,12 +318,50 @@ def get_interpolant(oldX,
     return interpolant
 
 
+def get_default_rational_fit_kwargs():
+    """Get default kwargs for rational fit."""
+    default_rational_fit_kwargs = {
+        "num_degree": None,
+        "denom_degree": None,
+        "norm": 2,
+        "maxiter": 20,
+        "verbose": False,
+        "xtol": 1e-07,
+    }
+    return default_rational_fit_kwargs
+
+
+def get_rational_fit(x, y, rational_fit_kwargs=None, check_kwargs=True):
+    """Get rational fit for the data set (x, y).
+
+    We use `polyrat.StabilizedSKRationalApproximation` to obtain
+    rational fit to the data.
+    """
+    if check_kwargs:
+        rational_fit_kwargs = check_kwargs_and_set_defaults(
+            rational_fit_kwargs,
+            get_default_rational_fit_kwargs(),
+            "rational_fit_kwargs",
+            "utils.get_default_rational_fit_kwargs"
+        )
+    # We use a rational approximation based on Stabilized Sanathanan-Koerner Iteration
+    # described in arXiv:2009.10803 and implemented in `polyrat.StabilizedSKRationalApproximation`.
+    rat = StabilizedSKRationalApproximation(**rational_fit_kwargs)
+    # The input x-axis data must be 2-dimensional
+    rat.fit(x.reshape(-1, 1), y)
+    # Using a lambda function to change the input 1-d data to
+    # float64 and reshape to 2-d as required by the fit.
+    # Ensure also that the input and output types are the same.
+    return lambda t: (rat(np.atleast_2d(t).astype('float64').reshape(-1, 1)).item() if np.isscalar(t)\
+                      else rat(np.atleast_2d(t).astype('float64').reshape(-1, 1)))
+
+
 def debug_message(message, debug_level, important=True,
                   point_to_verbose_output=False):
     """Show message based on debug_level.
 
-    parameters:
-    -----------
+    parameters
+    ----------
     message: str
         Message to display.
 
